MCD gerund
Commande ( commande, date )

- Le champ commande constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Commande.
- Le champ date était déjà un simple attribut de l'entité Commande.

Ligne de commande ( #commande, #produit, quantité )

- Le champ commande fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Commande pour renforcer l'identifiant.
- Le champ produit fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Produit pour renforcer l'identifiant.
- Le champ quantité était déjà un simple attribut de l'entité Ligne de commande.

Produit ( produit, libellé )

- Le champ produit constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Produit.
- Le champ libellé était déjà un simple attribut de l'entité Produit.